@@ -12,12 +12,13 @@ HTMLWidgets.widget({
     $('#lower-canvas').remove();
     $('#annotator_canvas').remove();
     $('#clear_annotations').remove();
+    $('#resize').remove();
+    $('#resize-width').remove();
     
     $('<canvas id="annotator_canvas"> </canvas>').appendTo(el);
     $('<button id="clear_annotations" class="button">Clear annotations</button>').appendTo(el);
 
-
-    annotator(el, x.im, x.W, x.H, x.resultId, x.brushWidth, x.brushColor, x.opacity, x.fill) 
+    annotator(el, x.im, x.resultId, x.brushWidth, x.brushColor, x.opacity, x.fill) 
 
     }
     
